IntoCfg

pub trait IntoCfg {
    // Required method
    fn into_cfg(
        self,
        curve: &Curve,
        reports: &mut ReportCollection,
    ) -> CFGResult<Cfg>;
}
This is a high level trait which simply wraps the implementation provided by TryLift. We need to pass the prime to the CFG here, to be able to do value propagation when converting to SSA.

Required Methods

fn into_cfg( self, curve: &Curve, reports: &mut ReportCollection, ) -> CFGResult<Cfg>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> IntoCfg for T
where T: TryLift<UsefulConstants, IR = Cfg, Error = CFGError>,