Module traits

Traits

DirectedGraphNode
This trait is used to make graph algorithms (like dominator tree and dominator frontier generation) generic over the graph node type for unit testing purposes.
SSABasicBlock
A basic block containing a (possibly empty) list of statements.
SSAConfig
SSAEnvironment
An environment used to track variable versions across a CFG.
SSAStatement
A statement in the language.

Type Aliases

Index
IndexSet