pub trait DirectedGraphNode {
// Required methods
fn index(&self) -> Index;
fn predecessors(&self) -> &IndexSet;
fn successors(&self) -> &IndexSet;
}Expand description
This trait is used to make graph algorithms (like dominator tree and dominator frontier generation) generic over the graph node type for unit testing purposes.
Required Methods
fn index(&self) -> Index
fn predecessors(&self) -> &IndexSet
fn successors(&self) -> &IndexSet
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".